# dNote

[![Build Status](https://travis-ci.com/yetisir/dnote.svg?branch=master)](https://travis-ci.com/yetisir/dnote)
[![Coverage Status](https://coveralls.io/repos/github/yetisir/dnote/badge.svg?branch=master)](https://coveralls.io/github/yetisir/dnote?branch=master)
[![Maintainability](https://api.codeclimate.com/v1/badges/9188bb54d74247ab039e/maintainability)](https://codeclimate.com/github/yetisir/dnote/maintainability)
[![Documentation Status](https://readthedocs.org/projects/dnote/badge/?version=latest)](https://dnote.readthedocs.io/en/latest/?badge=latest)

Simple CLI utility for managing notes on AWS


## Installation

dNote can be installed with [pip](https://pip.pypa.io/en/stable/).

```bash
python -m pip install dNote
```

## Usage

```bash
dnote new 'this is a new note!'
dnote new 'this is another new note.'
dnote new 'this is an old note'
dnote find 'new'
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[GNU GPLv3](https://choosealicense.com/licenses/gpl-3.0/)
